summaryrefslogtreecommitdiffstats
path: root/qtruby/rubylib/designer/rbuic/form.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'qtruby/rubylib/designer/rbuic/form.cpp')
-rw-r--r--qtruby/rubylib/designer/rbuic/form.cpp18
1 files changed, 9 insertions, 9 deletions
diff --git a/qtruby/rubylib/designer/rbuic/form.cpp b/qtruby/rubylib/designer/rbuic/form.cpp
index bbb0c7f6..42ec751f 100644
--- a/qtruby/rubylib/designer/rbuic/form.cpp
+++ b/qtruby/rubylib/designer/rbuic/form.cpp
@@ -95,12 +95,12 @@ void Uic::createFormImpl( const TQDomElement &e )
TQString objName = getObjectName( e );
if (hasKDEwidget) {
- out << indent << "retquire 'Korundum'" << endl << endl;
+ out << indent << "require 'Korundum'" << endl << endl;
} else {
- out << indent << "retquire 'Qt'" << endl << endl;
+ out << indent << "require 'Qt'" << endl << endl;
}
// generate local and local includes retquired
TQStringList globalIncludes, localIncludes;
TQStringList::Iterator it;
TQStringList sqlClasses;
@@ -416,14 +416,14 @@ void Uic::createFormImpl( const TQDomElement &e )
out << endl;
- // find out what images are retquired
- TQStringList retquiredImages;
+ // find out what images are required
+ TQStringList requiredImages;
static const char *imgTags[] = { "pixmap", "iconset", 0 };
for ( i = 0; imgTags[i] != 0; i++ ) {
nl = e.parentNode().toElement().elementsByTagName( imgTags[i] );
for ( int j = 0; j < (int) nl.length(); j++ ) {
TQString img = "@";
- retquiredImages += (img + nl.item(j).firstChild().toText().data());
+ requiredImages += (img + nl.item(j).firstChild().toText().data());
}
}
@@ -444,7 +444,7 @@ void Uic::createFormImpl( const TQDomElement &e )
for ( i = 0; i < (int) nl.length(); i++ )
{
TQString img = registerObject( nl.item(i).toElement().attribute( "name" ) );
- if ( !retquiredImages.contains( img ) )
+ if ( !requiredImages.contains( img ) )
continue;
TQDomElement tmp = nl.item(i).firstChild().toElement();
if ( tmp.tagName() != "data" )
@@ -612,7 +612,7 @@ void Uic::createFormImpl( const TQDomElement &e )
out << endl;
- // create all children, some forms have special retquirements
+ // create all children, some forms have special requirements
if ( objClass == "TQt::Wizard" )
{
@@ -795,7 +795,7 @@ void Uic::createFormImpl( const TQDomElement &e )
// handle application events if retquired
bool needFontEventHandler = false;
bool needSqlTableEventHandler = false;
bool needSqlDataBrowserEventHandler = false;
@@ -95,12 +95,12 @@ void Uic::createFormImpl( const TQDomElement &e )
}
- // generate local and local includes retquired
+ // generate local and local includes required
TQStringList globalIncludes, localIncludes;
TQStringList::Iterator it;
@@ -795,7 +795,7 @@ void Uic::createFormImpl( const TQDomElement &e )
{
- // handle application events if retquired
+ // handle application events if required
bool needFontEventHandler = false;
bool needSqlTableEventHandler = false;